from .pipelines import SSD512COCO
from .pipelines import SSD300VOC
from .pipelines import SSD512YCBVideo
from .pipelines import SSD300FAT
from .pipelines import DetectMiniXceptionFER
from .pipelines import MiniXceptionFER
from .pipelines import FaceKeypointNet2D32
from .pipelines import HeadPoseKeypointNet2D32
from .pipelines import HaarCascadeFrontalFace

from .pipelines import SinglePowerDrillPIX2POSE6D
from .pipelines import MultiPowerDrillPIX2POSE6D
from .pipelines import PIX2POSEPowerDrill
from .pipelines import PIX2YCBTools6D

from .pipelines import HigherHRNetHumanPose2D
from .pipelines import DetNetHandKeypoints
from .pipelines import MinimalHandPoseEstimation
from .pipelines import DetectMinimalHand
from .pipelines import ClassifyHandClosure
from .pipelines import SSD512MinimalHandPose
